==> project_3_16122025.zip: project_3/controllers/header.php <==
<?php


require_once('config.php');





if(($response["error"] == true))
{
    echo(json_encode($response));
}

if(($response["error"] == false))
{
    if((isset($_POST["request"])) && ($_POST["request"] == "get_header"))
    {

        $html   =   '<div class="container-fluid container-xl position-relative d-flex align-items-center justify-content-between">';
        $html  .=   '<a href="'.$base_url.'" class="logo d-flex align-items-center">';
        $html  .=   '<img src="'.$base_url.'assets/img/logo_3.png" alt="Goldfayre">';
        $html  .=   '</a>';
        $html  .=   '<nav id="navmenu" class="navmenu">';
        $html  .=   '<ul>';
        $html  .=   '<li><a href="'.$base_url.'">Home</a></li>';
        $html  .=   '<li><a href="'.$base_url.'about.html">About</a></li>';
        $html  .=   '<li><a href="'.$base_url.'our-management">Our Management</a></li>';
        $html  .=   '<li><a href="'.$base_url.'shop">Shop</a></li>';
        $html  .=   '<li><a href="'.$base_url.'contact_us.html">Contact</a></li>';
        if((isset($_SESSION["GOLDFAYRE"])))
        {
            $html  .=   '<li class="dropdown">';
            $html  .=   '<a href="#"><span>Hi, Qasim Ihsan</span> <i class="bi bi-chevron-down toggle-dropdown"></i></a>';
            $html  .=   '<ul>';
            $html  .=   '<li><a href="#" class="logout">Logout</a></li>';
            $html  .=   '</ul>';
            $html  .=   '</li>';
        }
        else
        {
            $html  .=   '<li><a href="signin">Sign In</a></li>';
        }
        $html  .=   '</ul>';
        $html  .=   '<i class="mobile-nav-toggle d-xl-none bi bi-list"></i>';
        $html  .=   '</nav>';
        $html  .=   '</div>';
        $response["html"]   =   $html;
        echo(json_encode($response));
    }

}












































?>

==> project_3_23122025.zip: project_3/controllers/header.php <==
<?php


require_once('config.php');





if(($response["error"] == true))
{
    echo(json_encode($response));
}

if(($response["error"] == false))
{
    if((isset($_POST["request"])) && ($_POST["request"] == "get_header"))
    {

        $html   =   '<div class="container-fluid container-xl position-relative d-flex align-items-center justify-content-between">';
        $html  .=   '<a href="'.$base_url.'" class="logo d-flex align-items-center">';
        $html  .=   '<img src="'.$base_url.'assets/img/logo_3.png" alt="Goldfayre">';
        $html  .=   '</a>';
        $html  .=   '<nav id="navmenu" class="navmenu">';
        $html  .=   '<ul>';
        $html  .=   '<li><a href="'.$base_url.'">Home</a></li>';
        $html  .=   '<li><a href="'.$base_url.'about.html">About</a></li>';
        $html  .=   '<li class="dropdown">';
        $html  .=   '<a href="'.$base_url.'our-management"><span>Our Mangement</span> <i class="bi bi-chevron-down toggle-dropdown"></i></a>';
        $html  .=   '<ul>';
        $html  .=   '<li><a href="'.$base_url.'ceo-message.html">CEO Message</a></li>';
        $html  .=   '</ul>';
        $html  .=   '</li>';
        $html  .=   '<li><a href="'.$base_url.'shop">Shop</a></li>';
        $html  .=   '<li><a href="'.$base_url.'contact_us.html">Contact</a></li>';
        if((isset($_SESSION["GOLDFAYRE"])))
        {
            $html  .=   '<li class="dropdown">';
            $html  .=   '<a href="#"><span>Hi, Qasim Ihsan</span> <i class="bi bi-chevron-down toggle-dropdown"></i></a>';
            $html  .=   '<ul>';
            $html  .=   '<li><a href="#" class="logout">Logout</a></li>';
            $html  .=   '</ul>';
            $html  .=   '</li>';
        }
        else
        {
            $html  .=   '<li><a href="signin">Sign In</a></li>';
        }
        $html  .=   '</ul>';
        $html  .=   '<i class="mobile-nav-toggle d-xl-none bi bi-list"></i>';
        $html  .=   '</nav>';
        $html  .=   '</div>';
        $response["html"]   =   $html;

        
        echo(json_encode($response));
    }

}












































?>
